@@ -21,6 +21,7 @@ if TYPE_CHECKING:
     from cleo.testers.command_tester import CommandTester
     from poetry.poetry import Poetry
     from poetry.repositories import Repository
+    from pytest_mock import MockerFixture
 
     from tests.types import CommandTesterFactory
     from tests.types import ProjectFactory
@@ -134,6 +135,18 @@ def test_export_fails_on_invalid_format(tester: CommandTester, do_lock: None) ->
         tester.execute("--format invalid")
 
 
+def test_export_fails_if_lockfile_is_not_fresh(
+    tester: CommandTester,
+    poetry: Poetry,
+    tmp_path: Path,
+    do_lock: None,
+    mocker: MockerFixture,
+) -> None:
+    mocker.patch.object(poetry.locker, "is_fresh", return_value=False)
+    assert tester.execute() == 1
+    assert "pyproject.toml changed significantly" in tester.io.fetch_error()
+
+
 def test_export_prints_to_stdout_by_default(
     tester: CommandTester, do_lock: None
 ) -> None:
@@ -237,6 +250,27 @@ def test_extras_conflicts_all_extras(tester: CommandTester, do_lock: None) -> No
     )
 
 
+def test_export_with_all_groups(tester: CommandTester, do_lock: None) -> None:
+    tester.execute("--format requirements.txt --all-groups")
+    output = tester.io.fetch_output()
+    assert f"baz==2.0.0 ; {MARKER_PY}" in output
+    assert f"opt==2.2.0 ; {MARKER_PY}" in output
+
+
+@pytest.mark.parametrize("flag", ["--with", "--without", "--only"])
+def test_with_conflicts_all_groups(
+    tester: CommandTester, do_lock: None, flag: str
+) -> None:
+    tester.execute(f"{flag}=bar --all-groups")
+
+    assert tester.status_code == 1
+    assert (
+        "You cannot specify explicit `--with`, `--without`,"
+        " or `--only` while exporting using `--all-groups`.\n"
+        in tester.io.fetch_error()
+    )
+
+
 def test_export_with_urls(
     monkeypatch: MonkeyPatch, tester: CommandTester, poetry: Poetry
 ) -> None:
