@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
-from typing import Protocol  # noqa: TYP001
+from typing import Protocol
 
 
 if TYPE_CHECKING:
@@ -14,14 +14,13 @@ if TYPE_CHECKING:
 
 class CommandTesterFactory(Protocol):
     def __call__(
-        self: CommandTester,
+        self,
         command: str,
         poetry: Poetry | None = None,
         installer: Installer | None = None,
         executor: Executor | None = None,
         environment: Env | None = None,
-    ) -> CommandTester:
-        ...
+    ) -> CommandTester: ...
 
 
 class ProjectFactory(Protocol):
@@ -33,5 +32,4 @@ class ProjectFactory(Protocol):
         pyproject_content: str | None = None,
         poetry_lock_content: str | None = None,
         install_deps: bool = True,
-    ) -> Poetry:
-        ...
+    ) -> Poetry: ...
